@@ -36,14 +36,14 @@ class ACIChunkUpdateHandlerABC(metaclass=ABCMeta):
     """
 
     _ChunkedTuple: ACIEncodedChunkTupleABC = None
-    _updateFromServerFilt: Dict = None
+    _updateFromLogicFilt: Dict = None
     _logger: logging.Logger = None
 
     def __init__(self, dbSessionCreator):
         self._dbSessionCreator = dbSessionCreator
 
         self._registerInterestObserver = PayloadEndpoint(
-            self._updateFromServerFilt, self._processRegisterInterest
+            self._updateFromLogicFilt, self._processRegisterInterest
         )
 
         self._vortexUuidsToSendTo = set()
@@ -52,6 +52,7 @@ class ACIChunkUpdateHandlerABC(metaclass=ABCMeta):
         pass
 
     def _processRegisterInterest(self, vortexUuid: str, **kwargs):
+        self._logger.debug("Received interest registration from %s", vortexUuid)
         self._vortexUuidsToSendTo.add(vortexUuid)
 
     def sendChunks(self, chunkKeys: List[str]) -> None:
@@ -182,7 +183,7 @@ class ACIChunkUpdateHandlerABC(metaclass=ABCMeta):
             return None
 
         return (
-            PayloadEnvelope(filt=cls._updateFromServerFilt, data=results)
+            PayloadEnvelope(filt=cls._updateFromLogicFilt, data=results)
             .toVortexMsg()
             .decode()
         )
