@@ -1,28 +1,34 @@
-import os
 import typing
-from abc import ABCMeta, abstractmethod
-from collections import deque, namedtuple
-from datetime import datetime, timedelta
+from abc import ABCMeta
+from abc import abstractmethod
+from collections import deque
+from collections import namedtuple
+from datetime import datetime
+from datetime import timedelta
 from logging import Logger
 from random import random
 from time import sleep
-from typing import List, Deque, Callable, Optional
+from typing import Callable
+from typing import Deque
+from typing import List
+from typing import Optional
 
-import psutil
 import pytz
-from psycopg2.extensions import (
-    ISOLATION_LEVEL_AUTOCOMMIT,
-    ISOLATION_LEVEL_DEFAULT,
-)
-from sqlalchemy import select, asc
+from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT
+from psycopg2.extensions import ISOLATION_LEVEL_DEFAULT
+from sqlalchemy import asc
+from sqlalchemy import select
 from sqlalchemy.dialects import postgresql
-from twisted.internet import task, reactor, defer
-from twisted.internet.defer import inlineCallbacks, Deferred, DeferredSemaphore
-from vortex.DeferUtil import (
-    deferToThreadWrapWithLogger,
-    vortexLogFailure,
-    nonConcurrentMethod,
-)
+from twisted.internet import defer
+from twisted.internet import reactor
+from twisted.internet import task
+from twisted.internet.defer import Deferred
+from twisted.internet.defer import DeferredSemaphore
+from twisted.internet.defer import inlineCallbacks
+from twisted.internet.task import deferLater
+from vortex.DeferUtil import deferToThreadWrapWithLogger
+from vortex.DeferUtil import nonConcurrentMethod
+from vortex.DeferUtil import vortexLogFailure
 from vortex.Payload import Payload
 
 from peek_abstract_chunked_index.private.server.controller.ACIProcessorStatusNotifierABC import (
@@ -33,6 +39,7 @@ from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import
 )
 from peek_plugin_base.LoopingCallUtil import peekCatchErrbackWithLogger
 from peek_plugin_base.storage.RunPyInPg import runPyInPg
+from peek_plugin_base.util.PeekPsUtil import PeekPsUtil
 
 ACIProcessorQueueBlockItem = namedtuple(
     "ACIProcessorQueueBlockItem",
@@ -58,6 +65,7 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
     """
 
     MAX_CPU_PERCENTAGE = 80.00
+    MAX_CPU_BACKOFF_SECONDS = 5.00
 
     QUEUE_ITEMS_PER_TASK: int = None  # Example 500
     POLL_PERIOD_SECONDS: float = None  # Example 0.200
@@ -106,8 +114,6 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         self._pausedForDuplicate = None
         self._fetchedBlockBuffer: Deque[ACIProcessorQueueBlockItem] = deque()
 
-        self._process = psutil.Process(os.getpid())
-
         assert self.QUEUE_ITEMS_PER_TASK, "ACI, QUEUE_ITEMS_PER_TASK is missing"
         assert self.POLL_PERIOD_SECONDS, "ACI, POLL_PERIOD_SECONDS is missing"
         assert self.QUEUE_BLOCKS_MAX, "ACI, QUEUE_BLOCKS_MAX is missing"
@@ -125,9 +131,12 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
             self.VACUUM_PERIOD_SECONDS
         ), "ACI, VACUUM_PERIOD_SECONDS is missing"
 
-    def _randomiseTimeDelta(self, seconds: int) -> timedelta:
+    # noinspection PyMethodMayBeStatic
+    def _randomiseTimeDelta(
+        self, seconds: typing.Union[float, int], variance=0.20
+    ) -> timedelta:
         # Randomise the time delta by up to +/- 20%
-        delta = seconds * 0.20 * (random() - 0.5)
+        delta = seconds * variance * (random() - 0.5)
         return timedelta(seconds=seconds + delta)
 
     def isBusy(self) -> bool:
@@ -179,9 +188,17 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
             return
 
         # If the CPU usage for this python process is too high, then skip this round
-        num = self._process.cpu_percent()
+        num = PeekPsUtil().cpuPercent
         if self.MAX_CPU_PERCENTAGE < num:
-            self._logger.debug("Skipping this loop, CPU is too high: %s", num)
+            cpuBackoffSeconds = self._randomiseTimeDelta(
+                self.MAX_CPU_BACKOFF_SECONDS, variance=0.5
+            ).total_seconds()
+            self._logger.info(
+                "Skipping this loop for %s seconds, CPU is too " "high: %s",
+                cpuBackoffSeconds,
+                num,
+            )
+            yield deferLater(reactor, cpuBackoffSeconds, lambda: None)
             return
 
         fetchedBlocks = yield self._fetchBlocks()
