@@ -35,13 +35,19 @@ class ACIProcessorStatusControllerABC(metaclass=ABCMeta):
 
         self._notifyPending = True
 
-        deltaSeconds = (datetime.now(pytz.utc) - self._lastNotifyDatetime).seconds
+        deltaSeconds = (
+            datetime.now(pytz.utc) - self._lastNotifyDatetime
+        ).seconds
         if deltaSeconds >= self.NOTIFY_PERIOD:
             self._sendNotify()
         else:
-            reactor.callLater(self.NOTIFY_PERIOD - deltaSeconds, self._sendNotify)
+            reactor.callLater(
+                self.NOTIFY_PERIOD - deltaSeconds, self._sendNotify
+            )
 
     def _sendNotify(self):
+        if not self._tupleObservable:
+            return
         self._notifyPending = False
         self._lastNotifyDatetime = datetime.now(pytz.utc)
         self._tupleObservable.notifyOfTupleUpdate(
